@@ -1,9 +1,9 @@
 #' Depend on another package
 #'
 #' `use_package()` adds a CRAN package dependency to `DESCRIPTION` and offers a
-#' little advice about how to best use it. `use_dev_package()` adds a versioned
-#' dependency on an in-development GitHub package, adding the repo to `Remotes`
-#' so it will be automatically installed from the correct location.
+#' little advice about how to best use it. `use_dev_package()` adds a
+#' dependency on an in-development package, adding the dev repo to `Remotes` so
+#' it will be automatically installed from the correct location.
 #'
 #' @param package Name of package to depend on.
 #' @param type Type of dependency: must be one of "Imports", "Depends",
@@ -11,9 +11,16 @@
 #'   is case insensitive.
 #' @param min_version Optionally, supply a minimum version for the package.
 #'   Set to `TRUE` to use the currently installed version.
+#' @param remote By default, an `OWNER/REPO` GitHub remote is inserted.
+#'   Optionally, you can supply a character string to specify the remote, e.g.
+#'   `"gitlab::jimhester/covr"`, using any syntax supported by the [remotes
+#'   package](
+#'   https://remotes.r-lib.org/articles/dependencies.html#other-sources).
+#'
 #' @seealso The [dependencies
 #'   section](https://r-pkgs.org/description.html#dependencies) of [R
 #'   Packages](https://r-pkgs.org).
+#'
 #' @export
 #' @examples
 #' \dontrun{
@@ -22,39 +29,46 @@
 #' use_dev_package("glue")
 #' }
 use_package <- function(package, type = "Imports", min_version = NULL) {
-
   if (type == "Imports") {
-    refuse_package(package, verboten = "tidyverse")
+    refuse_package(package, verboten = c("tidyverse", "tidymodels"))
   }
 
-  use_dependency(package, type, min_version = min_version)
-  how_to_use(package, type)
+  changed <- use_dependency(package, type, min_version = min_version)
+  if (changed) {
+    how_to_use(package, type)
+  }
 
   invisible()
 }
 
 #' @export
 #' @rdname use_package
-use_dev_package <- function(package, type = "Imports") {
-  refuse_package(package, verboten = "tidyverse")
+use_dev_package <- function(package, type = "Imports", remote = NULL) {
+  refuse_package(package, verboten = c("tidyverse", "tidymodels"))
 
-  use_dependency(package, type = type, min_version = TRUE)
-  use_remote(package)
-  how_to_use(package, type)
+  changed <- use_dependency(package, type = type, min_version = TRUE)
+  use_remote(package, remote)
+  if (changed) {
+    how_to_use(package, type)
+  }
 
   invisible()
 }
 
-use_remote <- function(package) {
+use_remote <- function(package, package_remote = NULL) {
   remotes <- desc::desc_get_remotes(proj_get())
   if (any(grepl(package, remotes))) {
     return(invisible())
   }
 
-  package_remote <- package_remote(desc::desc(package = package))
-  ui_done(
-    "Adding {ui_value(package_remote)} to {ui_field('Remotes')} field in DESCRIPTION"
-  )
+  if (is.null(package_remote)) {
+    desc <- desc::desc(package = package)
+    package_remote <- package_remote(desc)
+  }
+
+  ui_done("
+    Adding {ui_value(package_remote)} to {ui_field('Remotes')} field in \\
+    DESCRIPTION")
   remotes <- c(remotes, package_remote)
   desc::desc_set_remotes(remotes, file = proj_get())
   invisible()
@@ -63,24 +77,38 @@ use_remote <- function(package) {
 # Helpers -----------------------------------------------------------------
 
 package_remote <- function(desc) {
-  package <- desc$get_field("Package")
   remote <- as.list(desc$get(c("RemoteType", "RemoteUsername", "RemoteRepo")))
 
-  is_valid_remote <- all(purrr::map_lgl(remote, ~ is_string(.x) && !is.na(.x)))
-  if (!is_valid_remote) {
-    ui_stop("{ui_value(package)} was not installed from a supported remote.")
+  is_recognized_remote <- all(map_lgl(remote, ~ is_string(.x) && !is.na(.x)))
+
+  if (is_recognized_remote) {
+    # non-GitHub remotes get a 'RemoteType::' prefix
+    if (!identical(remote$RemoteType, "github")) {
+      remote$RemoteUsername <- paste0(remote$RemoteType, "::", remote$RemoteUsername)
+    }
+    return(paste0(remote$RemoteUsername, "/", remote$RemoteRepo))
   }
 
-  # GitHub remotes don't get the 'RemoteType::' prefix
-  if (identical(remote$RemoteType, "github")) {
-    paste0(remote$RemoteUsername, "/", remote$RemoteRepo)
+  package <- desc$get_field("Package")
+  urls <- desc_urls(package, desc = desc)
+  urls <- urls[urls$is_github, ]
+  if (nrow(urls) < 1) {
+    ui_stop("Cannot determine remote for {ui_value(package)}")
+  }
+  parsed <- parse_github_remotes(urls$url[[1]])
+  remote <- paste0(parsed$repo_owner, "/", parsed$repo_name)
+  if (ui_yeah("
+    {ui_value(package)} was either installed from CRAN or local source.
+    Based on DESCRIPTION, we propose the remote: {ui_value(remote)}
+    Is this OK?")) {
+    remote
   } else {
-    paste0(remote$RemoteType, "::", remote$RemoteUsername, "/", remote$RemoteRepo)
+    ui_stop("Cannot determine remote for {ui_value(package)}")
   }
 }
 
 refuse_package <- function(package, verboten) {
-  if (identical(package, verboten)) {
+  if (package %in% verboten) {
     code <- glue("use_package(\"{package}\", type = \"depends\")")
     ui_stop(
       "{ui_value(package)} is a meta-package and it is rarely a good idea to \\
@@ -119,7 +147,9 @@ how_to_use <- function(package, type) {
 show_includes <- function(package) {
   incl <- path_package("include", package = package)
   h <- dir_ls(incl, regexp = "[.](h|hpp)$")
-  if (length(h) == 0) return()
+  if (length(h) == 0) {
+    return()
+  }
 
   ui_todo("Possible includes are:")
   ui_code_block("#include <{path_file(h)}>", copy = FALSE)
